# -*- coding: utf-8 -*-
from fargo.dom import Tag
from fargo.style import CSS


class BaseTag(Tag):
    def __init__(self, *args, **kwargs):
        super(BaseTag, self).__init__(*args, **kwargs)
        if self.__class__.__bases__[0].__name__ == 'BaseTag' or self.__class__.__name__ == 'BaseTag':
            del self.params['class']


class Html(BaseTag):
    def __init__(self, inner):
        super(Html, self).__init__('html', inner=inner)

    def __str__(self):
        return '<!DOCTYPE html>\n%s' % super(Html, self).__str__()


class Head(BaseTag):
    def __init__(self, text):
        super(Head, self).__init__('head', inner=text)


class Title(BaseTag):
    def __init__(self, text):
        super(Title, self).__init__('title', inner=text)


class Meta(BaseTag):
    def __init__(self, params):
        super(Meta, self).__init__('meta', params=params, pair=False)


class Style(BaseTag, CSS):
    def __init__(self):
        inner = CSS().css()
        super(Style, self).__init__('style', inner=inner)


class Link(BaseTag):
    def __init__(self, params):
        super(Link, self).__init__('link', params=params, pair=False)


class Script(BaseTag):
    def __init__(self, inner, params=None):
        super(Script, self).__init__('script', inner=inner, params=params)


class Body(BaseTag):
    def __init__(self, inner):
        super(Body, self).__init__('body', inner=inner)


class Div(BaseTag):
    def __init__(self, inner, params=None):
        super(Div, self).__init__('div', inner=inner, params=params)


class P(BaseTag):
    def __init__(self, text, params=None):
        super(P, self).__init__('p', inner=text, params=params)


class H1(BaseTag):
    def __init__(self, text, params=None):
        super(H1, self).__init__('h1', inner=text, params=params)


class A(BaseTag):
    def __init__(self, text, href, params=None):
        if params is None:
            params = {}
        params.update({'href': href})
        super(A, self).__init__('a', params=params, inner=text)


class Img(BaseTag):
    def __init__(self, src, alt, params=None):
        if params is None:
            params = {}
        params.update({'src': src, 'alt': alt})
        super(Img, self).__init__('img', params=params, pair=False)


class Ul(BaseTag):
    def __init__(self, text, params=None):
        super(Ul, self).__init__('ul', inner=text, params=params)


class Li(BaseTag):
    def __init__(self, text, params=None):
        super(Li, self).__init__('li', inner=text, params=params)
